@@ -3,6 +3,7 @@ import re
 import time
 from contextlib import contextmanager
 from functools import wraps
+from pathlib import Path
 from textwrap import dedent
 from typing import Optional
 
@@ -64,6 +65,8 @@ def boto_client(saml_client, service):
 
 @intercept_boto_errors
 def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: SymConfigFile):
+    saml_client.dprint("sending SSH key")
+
     user = get_ssh_user()
     ssm_client = boto_client(saml_client, "ssm")
     # fmt: off
@@ -109,6 +112,8 @@ def find_instance(saml_client, keys, value) -> Optional[str]:
     if (cached := Config.find_instance_by_alias(value)) :
         return cached
 
+    saml_client.dprint(f"finding instance", keys=keys, value=value)
+
     ec2_client = boto_client(saml_client, "ec2")
     for key in keys:
         paginator = ec2_client.get_paginator("describe_instances")
@@ -131,6 +136,8 @@ def get_identity(saml_client) -> dict:
 
 
 def host_to_instance(saml_client, host: str) -> str:
+    saml_client.dprint(f"finding instance: host={host}")
+
     if InstanceIDPattern.match(host):
         target = host
     elif validators.ip_address.ipv4(host):
@@ -167,3 +174,14 @@ def ssm_session(saml_client, instance: str, port: int):
         yield command
     finally:
         ssm_client.terminate_session(SessionId=response["SessionId"])
+
+
+@intercept_boto_errors
+def put_file(saml_client, bucket: str, file_path: Path, object_path: str):
+    s3_client = boto_client(saml_client, "s3")
+    s3_client.upload_file(
+        str(file_path),
+        bucket,
+        object_path,
+        ExtraArgs={"ACL": "bucket-owner-full-control"},
+    )
