@@ -28,7 +28,7 @@ ConfigKey = Literal["org", "email"]
 
 def xdg_config_home() -> Path:
     try:
-        return Path(os.environ["XDG_CONFIG_HOME"]).resolve()
+        return Path(os.environ["XDG_CONFIG_HOME"]).expanduser().resolve()
     except KeyError:
         return Path.home() / ".config"
 
