@@ -1,6 +1,7 @@
 from multiprocessing import Pool
 
 import pytest
+from expects import *
 
 from sym.cli.helpers.config import SymConfigFile
 from sym.cli.saml_clients.saml2aws import Saml2Aws
@@ -16,7 +17,6 @@ pytestmark = [
 def test_saml2aws(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
-    capture_command.enqueue_outputs("AWS_REGION=foobar\nAWS_FOOBAR=baz")
     with test_context(debug=False) as saml2aws:
         with capture_command():
             saml2aws.exec("aws", "ssm", "start-session", target="i-0123456789abcdef")
@@ -28,20 +28,17 @@ def test_saml2aws(
 
 
 def test_saml2aws_get_creds(
-    test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
+    test_context: TestContextFixture[Saml2Aws],
+    capture_command: CaptureCommand,
 ) -> None:
-    capture_command.enqueue_outputs(
-        "AWS_REGION=foobar\nAWS_FOOBAR=baz", "", "AWS_REGION=foobar\nAWS_FOOBAR=baz"
-    )
     with test_context(debug=False) as saml2aws:
         with capture_command():
-            assert saml2aws.get_creds() == {"AWS_REGION": "foobar"}
+            expect(saml2aws.get_creds()).to(have_keys({"AWS_REGION": "foobar"}))
 
 
 def test_saml2aws_debug(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
-    capture_command.enqueue_outputs("AWS_REGION=foobar\nAWS_FOOBAR=baz")
     with test_context(debug=True) as saml2aws:
         with capture_command():
             saml2aws.exec("env")
